==> mule-semantic-terms-extension-4.5.0-20221117-sources.jar: org/mule/test/semantic/extension/SemanticTermsExtension.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.test.semantic.extension;

import org.mule.runtime.extension.api.annotation.Extension;
import org.mule.runtime.extension.api.annotation.Operations;
import org.mule.runtime.extension.api.annotation.Sources;
import org.mule.runtime.extension.api.annotation.connectivity.ConnectionProviders;
import org.mule.test.semantic.extension.connection.ApiKeySemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.BasicAuthSemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.ClientSecretSemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.CustomAuthSemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.DigestSemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.KerberosSemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.UnsecuredSemanticConnectionProvider;

@Extension(name = "Semantic Terms")
@Operations(SemanticTermsOperations.class)
@ConnectionProviders({BasicAuthSemanticConnectionProvider.class, ApiKeySemanticConnectionProvider.class,
    ClientSecretSemanticConnectionProvider.class, CustomAuthSemanticConnectionProvider.class,
    DigestSemanticConnectionProvider.class, KerberosSemanticConnectionProvider.class,
    UnsecuredSemanticConnectionProvider.class})
@Sources(SemanticTermsSource.class)
public class SemanticTermsExtension {

}

==> mule-semantic-terms-extension-4.6.25-20251107.041149-8-sources.jar: org/mule/test/semantic/extension/SemanticTermsExtension.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.test.semantic.extension;

import static org.mule.sdk.api.meta.JavaVersion.JAVA_11;
import static org.mule.sdk.api.meta.JavaVersion.JAVA_17;
import static org.mule.sdk.api.meta.JavaVersion.JAVA_8;

import org.mule.runtime.extension.api.annotation.Extension;
import org.mule.runtime.extension.api.annotation.Operations;
import org.mule.runtime.extension.api.annotation.Sources;
import org.mule.runtime.extension.api.annotation.connectivity.ConnectionProviders;
import org.mule.sdk.api.annotation.JavaVersionSupport;
import org.mule.test.semantic.extension.connection.ApiKeySemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.BasicAuthSemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.ClientSecretSemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.CustomAuthSemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.DigestSemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.KerberosSemanticConnectionProvider;
import org.mule.test.semantic.extension.connection.UnsecuredSemanticConnectionProvider;

@Extension(name = "Semantic Terms")
@JavaVersionSupport({JAVA_8, JAVA_11, JAVA_17})
@Operations(SemanticTermsOperations.class)
@ConnectionProviders({BasicAuthSemanticConnectionProvider.class, ApiKeySemanticConnectionProvider.class,
    ClientSecretSemanticConnectionProvider.class, CustomAuthSemanticConnectionProvider.class,
    DigestSemanticConnectionProvider.class, KerberosSemanticConnectionProvider.class,
    UnsecuredSemanticConnectionProvider.class})
@Sources(SemanticTermsSource.class)
public class SemanticTermsExtension {

}
